Similar to the PowerMac3,1, the PowerBook6,7 is missing the #size-cells
property on the i2s node.

Depends-on: 045b14ca5c36 ("of: WARN on deprecated #address-cells/#size-cells 
handling")
Signed-off-by: Andreas Schwab <sch...@linux-m68k.org>
---
 arch/powerpc/kernel/prom_init.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/arch/powerpc/kernel/prom_init.c b/arch/powerpc/kernel/prom_init.c
index 8e776ba39497..24b1523eeea8 100644
--- a/arch/powerpc/kernel/prom_init.c
+++ b/arch/powerpc/kernel/prom_init.c
@@ -2898,11 +2898,11 @@ static void __init fixup_device_tree_pmac(void)
        char type[8];
        phandle node;
 
        // Some pmacs are missing #size-cells on escc nodes
        for (node = 0; prom_next_node(&node); ) {
                type[0] = '\0';
                prom_getprop(node, "device_type", type, sizeof(type));
-               if (prom_strcmp(type, "escc"))
+               if (prom_strcmp(type, "escc") && prom_strcmp(type, "i2s"))
                        continue;
 
                if (prom_getproplen(node, "#size-cells") != PROM_ERROR)
@@ -2898,11 +2898,11 @@ static void __init fixup_device_tree_pmac(void)
        phandle node;
 
-       // Some pmacs are missing #size-cells on escc nodes
+       // Some pmacs are missing #size-cells on escc or i2s nodes
        for (node = 0; prom_next_node(&node); ) {
                type[0] = '\0';
-- 
2.48.0


-- 
Andreas Schwab, sch...@linux-m68k.org
GPG Key fingerprint = 7578 EB47 D4E5 4D69 2510  2552 DF73 E780 A9DA AEC1
"And now for something completely different."

Reply via email to